package com.ruoyi.mall.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.mall.mapper.UserChoosetypeMapper ;
import com.ruoyi.mall.domain.UserChoosetype ;
import com.ruoyi.mall.service.IUserChoosetypeService ;

/**
 * 【请填写功能名称】Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-01-24
 */
@Service
public class UserChoosetypeServiceImpl implements IUserChoosetypeService 
{
    @Autowired
    private UserChoosetypeMapper userChoosetypeMapper;

    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    @Override
    public UserChoosetype selectUserChoosetypeById(Long id)
    {
        return userChoosetypeMapper.selectUserChoosetypeById(id);
    }

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param userChoosetype 【请填写功能名称】
     * @return 【请填写功能名称】
     */
    @Override
    public List<UserChoosetype> selectUserChoosetypeList(UserChoosetype userChoosetype)
    {
        return userChoosetypeMapper.selectUserChoosetypeList(userChoosetype);
    }

    /**
     * 新增【请填写功能名称】
     * 
     * @param userChoosetype 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int insertUserChoosetype(UserChoosetype userChoosetype)
    {
        userChoosetype.setCreateTime(DateUtils.getNowDate());
        return userChoosetypeMapper.insertUserChoosetype(userChoosetype);
    }

    /**
     * 修改【请填写功能名称】
     * 
     * @param userChoosetype 【请填写功能名称】
     * @return 结果
     */
    @Override
    public int updateUserChoosetype(UserChoosetype userChoosetype)
    {
        return userChoosetypeMapper.updateUserChoosetype(userChoosetype);
    }

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteUserChoosetypeByIds(Long[] ids)
    {
        return userChoosetypeMapper.deleteUserChoosetypeByIds(ids);
    }

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
    @Override
    public int deleteUserChoosetypeById(Long id)
    {
        return userChoosetypeMapper.deleteUserChoosetypeById(id);
    }

    @Override
    public void deleteUserChoosetypeByUser(Long userId) {
        userChoosetypeMapper.deleteUserChoosetypeByUser(userId);
    }

    @Override
    public void insertUserChoosetypebatch(List<UserChoosetype> userchoosetypelist) {
        userChoosetypeMapper.insertUserChoosetypebatch(userchoosetypelist);
    }

    @Override
    public List<UserChoosetype> selectUserChoosetypeByuserid(Long userId) {
        return  userChoosetypeMapper.selectUserChoosetypeByuserId(userId);
    }
}
