package com.ruoyi.controller;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.mall.domain.UserChoosetype;
import com.ruoyi.mall.service.IUserChoosetypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 【请填写功能名称】Controller
 *
 * @author ruoyi
 * @date 2025-01-24
 */
@RestController
@RequestMapping("/system/choosetype")
public class UserChoosetypeController extends BaseController {
    @Autowired
    private IUserChoosetypeService userChoosetypeService;

    /**
     * 查询【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:choosetype:list')")
    @GetMapping("/list")
    public TableDataInfo list(UserChoosetype userChoosetype) {
        startPage();
        List<UserChoosetype> list = userChoosetypeService.selectUserChoosetypeList(userChoosetype);
        return getDataTable(list);
    }

    /**
     * 导出【请填写功能名称】列表
     */
    @PreAuthorize("@ss.hasPermi('system:choosetype:export')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, UserChoosetype userChoosetype) {
        List<UserChoosetype> list = userChoosetypeService.selectUserChoosetypeList(userChoosetype);
        ExcelUtil<UserChoosetype> util = new ExcelUtil<UserChoosetype>(UserChoosetype.class);
        util.exportExcel(response, list, "【请填写功能名称】数据");
    }

    /**
     * 获取【请填写功能名称】详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:choosetype:query')")
    @GetMapping(value = "/{id}")
    public Object getInfo(@PathVariable("id") Long id) {
        return userChoosetypeService.selectUserChoosetypeById(id);
    }

    /**
     * 新增【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:choosetype:add')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody UserChoosetype userChoosetype) {
        return toAjax(userChoosetypeService.insertUserChoosetype(userChoosetype));
    }

    /**
     * 修改【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:choosetype:edit')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody UserChoosetype userChoosetype) {
        return toAjax(userChoosetypeService.updateUserChoosetype(userChoosetype));
    }

    /**
     * 删除【请填写功能名称】
     */
    @PreAuthorize("@ss.hasPermi('system:choosetype:remove')")
    @Log(title = "【请填写功能名称】", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(userChoosetypeService.deleteUserChoosetypeByIds(ids));
    }
}
